@@ -39,7 +39,6 @@
 #include "eom-thumbnail.h"
 #include "eom-job-queue.h"
 #include "eom-application.h"
-#include "eom-plugin-engine.h"
 #include "eom-util.h"
 
 #include <string.h>
@@ -50,8 +49,10 @@
 #include <exempi/xmp.h>
 #endif
 
-#if GTK_CHECK_VERSION (3, 0, 0)
+#if GTK_CHECK_VERSION (3, 20, 0)
 #define EOM_CSS_FILE_PATH EOM_DATA_DIR G_DIR_SEPARATOR_S "eom.css"
+#else
+#define EOM_CSS_FILE_PATH EOM_DATA_DIR G_DIR_SEPARATOR_S "eom-3.18.css"
 #endif
 
 static EomStartupFlags flags;
@@ -191,21 +192,13 @@ main (int argc, char **argv)
 {
 	GError *error = NULL;
 	GOptionContext *ctx;
-#if GTK_CHECK_VERSION (3, 0, 0)
 	GtkCssProvider *provider;
-#endif
 
 	bindtextdomain (GETTEXT_PACKAGE, EOM_LOCALE_DIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
-#if !GTK_CHECK_VERSION (3, 0, 0)
-	gtk_rc_parse (EOM_DATA_DIR G_DIR_SEPARATOR_S "gtkrc");
-#endif
-
-#if GTK_CHECK_VERSION (3, 0, 0)
 	gdk_set_allowed_backends ("x11");
-#endif
 
 	ctx = g_option_context_new (NULL);
 	g_option_context_add_main_entries (ctx, goption_options, PACKAGE);
@@ -251,7 +244,6 @@ main (int argc, char **argv)
 	eom_job_queue_init ();
 	eom_thumbnail_init ();
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	/* Load special style properties for EomThumbView's scrollbar */
 	provider = gtk_css_provider_new ();
 	if (G_UNLIKELY (!gtk_css_provider_load_from_path(provider,
@@ -267,9 +259,6 @@ main (int argc, char **argv)
 				GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
 	}
 	g_object_unref (provider);
-#endif
-
-	eom_plugin_engine_init ();
 
 	/* Add application specific icons to search path */
 	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
@@ -280,21 +269,11 @@ main (int argc, char **argv)
 
 	load_files ();
 
-#if !GTK_CHECK_VERSION (3, 0, 0)
-	gdk_threads_enter ();
-#endif
-
 	gtk_main ();
 
-#if !GTK_CHECK_VERSION (3, 0, 0)
-	gdk_threads_leave ();
-#endif
-
   	if (startup_files)
 		g_strfreev (startup_files);
 
-	eom_plugin_engine_shutdown ();
-
 #ifdef HAVE_EXEMPI
 	xmp_terminate();
 #endif
